@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -30,7 +30,7 @@
 
 #include <QCloseEvent>
 #include <QLabel>
-#include <QNetworkConfigurationManager>
+#include <QMenu>
 #include <QPointer>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
@@ -58,14 +58,14 @@ SieveEditorMainWindow::SieveEditorMainWindow(QWidget *parent)
     setupGUI();
     readConfig();
     initStatusBar();
-    connect(PimCommon::NetworkManager::self()->networkConfigureManager(),
-            &QNetworkConfigurationManager::onlineStateChanged,
+    connect(PimCommon::NetworkManager::self(),
+            &PimCommon::NetworkManager::networkStatusChanged,
             this,
             &SieveEditorMainWindow::slotSystemNetworkOnlineStateChanged);
 
     connect(mMainWidget->sieveEditorMainWidget()->tabWidget(), &QTabWidget::currentChanged, this, &SieveEditorMainWindow::slotUpdateActions);
     connect(mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::modeEditorChanged, this, &SieveEditorMainWindow::slotUpdateActions);
-    slotSystemNetworkOnlineStateChanged(PimCommon::NetworkManager::self()->networkConfigureManager()->isOnline());
+    slotSystemNetworkOnlineStateChanged(PimCommon::NetworkManager::self()->isOnline());
     connect(mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::undoAvailable, this, &SieveEditorMainWindow::slotUndoAvailable);
     connect(mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::redoAvailable, this, &SieveEditorMainWindow::slotRedoAvailable);
     connect(mMainWidget->sieveEditorMainWidget(), &SieveEditorMainWidget::copyAvailable, this, &SieveEditorMainWindow::slotCopyAvailable);
@@ -276,7 +276,7 @@ void SieveEditorMainWindow::slotImportImapSettings()
 
 void SieveEditorMainWindow::slotRefreshList()
 {
-    if (PimCommon::NetworkManager::self()->networkConfigureManager()->isOnline()) {
+    if (PimCommon::NetworkManager::self()->isOnline()) {
         mMainWidget->sieveEditorMainWidget()->refreshList();
     }
 }
